# Contributors

* Yuliia Pavliuk ([@pav.yulia](https://crowdin.com/profile/pav.yulia))
* Steven Silvester ([@blink1073](https://crowdin.com/profile/blink1073))
* JupyterLab Bot ([@jupyterlab-bot](https://crowdin.com/profile/jupyterlab-bot))
* Oleksii Burdin ([@oleksiburdin](https://crowdin.com/profile/oleksiburdin))
* sahanshiii ([@sahanshiii](https://crowdin.com/profile/sahanshiii))
* Nathalie Rud ([@talka](https://crowdin.com/profile/talka))
* lodka ([@lodka](https://crowdin.com/profile/lodka))
* Serhiy Dmytryshyn ([@dies](https://crowdin.com/profile/dies))
* d.yankovskyi ([@d.yankovskyi](https://crowdin.com/profile/d.yankovskyi))
